//--------------------------------------------------------------
// File     : stm32_ub_bma180.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_BMA180_H
#define __STM32F4_UB_BMA180_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32_ub_spi4.h"


//--------------------------------------------------------------
// ChipSelect-Pin vom BMA180
//--------------------------------------------------------------
#define BMA180_CS_PIN         GPIO_Pin_2
#define BMA180_CS_GPIO_PORT   GPIOB
#define BMA180_CS_GPIO_CLK    RCC_AHB1Periph_GPIOB


//--------------------------------------------------------------
// Adressen der Register vom BMA180
//--------------------------------------------------------------
#define BMA180_REG_ID       0x00
#define BMA180_REG_XLSB     0x02
#define BMA180_REG_XMSB     0x03
#define BMA180_REG_YLSB     0x04
#define BMA180_REG_YMSB     0x05
#define BMA180_REG_ZLSB     0x06
#define BMA180_REG_ZMSB     0x07
#define BMA180_REG_TEMP     0x08
#define BMA180_REG_CTRL0    0x0D
#define BMA180_REG_FILTER   0x20
#define BMA180_REG_RANGE    0x35


//--------------------------------------------------------------
// sonstige defines
//--------------------------------------------------------------
#define BMA180_ID_VALUE       0x03    // ID vom BMA180
#define BMA180_WRITE_DELAY    500000  // kleine Pause beim schreiben



// Auflsung
typedef enum {
  SCALE_1G =0,    // Auflsung +/- 1g
  SCALE_1G5,      // Auflsung +/- 1,5g
  SCALE_2G,       // Auflsung +/- 2g
  SCALE_3G,       // Auflsung +/- 3g
  SCALE_4G,       // Auflsung +/- 4g
  SCALE_8G,       // Auflsung +/- 8g
  SCALE_16G       // Auflsung +/- 16g
}BMA180_SCALE_t;


// Filter
typedef enum {
  FILTER_10Hz =0,    // Filter (10 Hz)
  FILTER_20Hz,       // Filter (20 Hz)
  FILTER_40Hz,       // Filter (40 Hz)
  FILTER_75Hz,       // Filter (75 Hz)
  FILTER_150Hz,      // Filter (150 Hz)
  FILTER_300Hz,      // Filter (300 Hz)
  FILTER_600Hz,      // Filter (600 Hz)
  FILTER_1200Hz,     // Filter (1200 Hz) [default]
  FILTER_HIGH_1Hz,   // Filter (High Pass 1Hz)
  FILTER_BAND_PASS   // Filter (Band Pass)
}BMA180_FILTER_t;



//--------------------------------------------------------------
// Umrechnungsfaktoren bei 14bit
//--------------------------------------------------------------
#define  BMA180_1G_FAKTOR    0.1220   // 0.13mg pro Digit (+/-1g)
#define  BMA180_1G5_FAKTOR   0.1831   // 0.19mg pro Digit (+/-1,5g)
#define  BMA180_2G_FAKTOR    0.2441   // 0.25mg pro Digit (+/-2g)
#define  BMA180_3G_FAKTOR    0.3662   // 0.38mg pro Digit (+/-3g)
#define  BMA180_4G_FAKTOR    0.4882   // 0.50mg pro Digit (+/-4g)
#define  BMA180_8G_FAKTOR    0.9765   // 0.99mg pro Digit (+/-8g)
#define  BMA180_16G_FAKTOR   1.9531   // 1.98mg pro Digit (+/-16g)



//--------------------------------------------------------------
// Globale Struktur vom BMA180
//--------------------------------------------------------------
typedef struct {
  int16_t x_achse;    // Beschl. der X-Achse (in +/- mg)
  int16_t y_achse;    // Beschl. der Y-Achse (in +/- mg)
  int16_t z_achse;    // Beschl. der Z-Achse (in +/- mg)
  int16_t temperatur; // Temperatur (in +/- C)
}BMA180_t;
BMA180_t BMA180;


//--------------------------------------------------------------
// RAW-Daten vom BMA180
//--------------------------------------------------------------
typedef struct {
  uint16_t x_achse;
  uint16_t y_achse;
  uint16_t z_achse;
  uint8_t temperatur;
  float faktor;
}BMA180_RAW_t;
BMA180_RAW_t BMA180_RAW;


//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_BMA180_Init(BMA180_SCALE_t scale);
void UB_BMA180_Read(void);
void UB_BMA180_SetFilter(BMA180_FILTER_t filter);



//--------------------------------------------------------------
#endif // __STM32F4_UB_BMA180_H
